unit MainForm; 

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, LResources, Forms, Controls, Graphics,
  Dialogs, StdCtrls, ExtCtrls, Buttons, IniFiles,
  {$ifdef Linux}
  Unix;
  {$else}
  ShellApi;
  {$endif}

type

  { TMain }

  TMain = class(TForm)
    btnTranslation: TButton;
    Edit1: TEdit;
    RadioGroup1: TRadioGroup;
    Memo2: TMemo;
    Button1: TButton;
    Memo3: TMemo;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    Button5: TButton;
    OpenDialog: TOpenDialog;
    procedure btnTranslationClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Edit1Change(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure RadioGroup1Click(Sender: TObject);
    procedure Memo2Enter(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Memo3Enter(Sender: TObject);
    procedure FormClose(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    procedure LoadDictionary;
    function GetExeName: String;
  public
    SL: TStringList;
  end;

var
  Main: TMain;
  n, nr, tale:integer;
  DicName, IniFileName, dumstr: String;
  Msg: array[0..10] of String;

implementation

uses TranslationForm;

//------------------------------------------------
procedure TMain.FormCreate(Sender: TObject);
var
  IniFile: TIniFile;
  S, ResourceFileName: String;
  i: Integer;
begin
  S := Self.Name;
  ResourceFileName := ChangeFileExt(Application.ExeName, '.lng');
  if FileExists(ResourceFileName) then
  begin
    IniFile := TIniFile.Create(ResourceFileName);
    with IniFile do
      try
        Caption                  := ReadString(S, 'Caption','');
        Button1.Caption          := ReadString(S, 'Button1.Caption','');
        Button2.Caption          := ReadString(S, 'Button2.Caption','');
        Button3.Caption          := ReadString(S, 'Button3.Caption','');
        Button4.Caption          := ReadString(S, 'Button4.Caption','');
        Button5.Caption          := ReadString(S, 'Button5.Caption','');
        btnTranslation.Caption   := ReadString(S, 'btnTranslation.Caption','');
        for i := 1 to 10 do
          Msg[i] := StringReplace(ReadString(S, 'Msg' + IntToStr(i), ''), '<br>',   #13#10 , [rfReplaceAll, rfIgnoreCase]);
      finally
        Free;
      end;
  end;
  {$ifdef Linux}
  IniFileName := GetEnvironmentVariable('HOME') + '/.TechEJ.ini';
  {$else}
  IniFileName := ChangeFileExt(GetExeName, '.ini');
  {$endif}
  IniFile := TIniFile.Create(IniFileName);
  try
    with IniFile do
    begin
      DicName := ReadString('Setting', 'Name of Dictionary',
      ExtractFilePath(GetExeName) + Msg[1]);
    end;
  finally
    IniFile.Free;
  end;
  SL := TStringList.Create;
end;

procedure TMain.btnTranslationClick(Sender: TObject);
begin
  Translation.Show;
end;

procedure TMain.LoadDictionary;
var S: String;
begin
  {$ifdef Linux}
  S := '1.2';
  {$else}
  S := '1.2';
  {$endif}
  Caption := ChangeFileExt(ExtractFileName(DicName), '') + ' - TechEJ ver.' + S;
  SL.Clear;
  if FileExists(DicName) then
    SL.LoadFromFile(DicName); // ファイルを全てMemo1に読み込む
    //  for i := 1 to 10 do SL.Add('');
  n := SL.Count;
end;

procedure TMain.FormShow(Sender: TObject);
begin
  Memo2.Height := (Font.Size + 16) * 10 + 4;
  Memo3.Height := Memo2.Height;
  {$ifdef Linux}
  Height := Memo2.Top + Memo2.Height + 20;
  {$else}
  Height := Memo2.Top + Memo2.Height + 50;
  {$endif}
  LoadDictionary;
end;

procedure TMain.Edit1Change(Sender: TObject);
var
  i, j, k: Integer;
begin
  if Radiogroup1.Itemindex = 1 then
    exit;
  if Edit1.Text <> '' then
    if Length(AnsiString(Edit1.Text)) = Length(WideString(Edit1.Text)) then
    begin
      j := 0; i := -1;
      k := Length(Edit1.Text);
      while j = 0 do
      begin
        if i > SL.Count - 2 then
        begin
          ShowMessage(Msg[2]);
          Exit;
        end;
        i := i + 1;
        dumstr := Copy(SL[i], 1, k);
        j := Pos(Edit1.text, dumstr);
      end;
      Memo2.Clear;
      Memo3.Clear;
      if i <= SL.Count - 1 then
        for j := 0 to 9 do
        begin
          try
            k := Pos(':', SL[i]);
            if k > 0 then
            begin
              dumstr := Copy(SL[i], 1, k - 1);
              Memo2.Lines.Add(dumstr);
              dumstr := SL[i];
              dumstr := Copy(SL[i], k + 1, Length(SL[i]) - k);
              Memo3.Lines.Add(TrimLeft(dumstr));
            end;
          except
          end;
          i := i + 1;
          if i = SL.Count - 1 then
            Break;
        end;
      tale := i - 1;
      Memo2.SelStart := 1;
      Memo3.SelStart := 1;
    end
    else
    begin
      RadioGroup1.ItemIndex := 1;
      Button1Click(Sender);
    end;
end;
//------------------------------------------------
procedure TMain.Button1Click(Sender: TObject);
var
  i, j, j2, k:integer;
begin
  Memo2.Clear;
  Memo3.Clear;
  i:= -1; k:= 0;
  while i < n-1 do
  begin
    i := i + 1;
    j := pos(Edit1.text,SL[i]);
    if j <> 0 then
    begin
      j2 := Pos(':',SL[i]);
      dumstr := Copy(SL[i], 1, j2 - 1);
      Memo2.Lines.Add(dumstr);
      dumstr := SL[i];
      dumstr := Copy(SL[i], j2 + 1, Length(SL[i])-j2);
      Memo3.Lines.Add(Trimleft(dumstr));
      k := k + 1;
    end;
    if k = 10 then
      break;
  end;
  if k = 0 then
    ShowMessage(Msg[2]);
  Edit1.SetFocus;
end;
//------------------------------------------------
procedure TMain.RadioGroup1Click(Sender: TObject);
begin
  if radiogroup1.itemindex=1 then
  begin
    button1.enabled:=true;
    button2.enabled:=False;
    edit1.setfocus
  end
  else
  begin
    button1.enabled:=false;
    button2.enabled:=True;
    edit1.setfocus
  end;
end;
//------------------------------------------------
procedure TMain.Button2Click(Sender: TObject);
var
  SLf: TStringList;
  i, j, k: Integer;
  S1: String;
begin
  Screen.Cursor  := crHourGlass;
  Button2.Enabled := False;
  nr := Memo2.Lines.Count;
  if nr <> 0 then
  begin
    SLf := TStringList.Create;
    try
      for j := 1 to tale - 10 do
        SLf.Add(SL[j]);
      S1 := Memo3.Text;
      for i := 0 to nr - 1 do
      begin
        k := Pos(#10, S1);
        S := Memo2.Lines[i] + ': ' + Copy(S1, 1, k - 1);
        SLf.Add(S);
        S1 := Copy(S1, k+1, 1000);
      end;
      for  j := tale + 1 to SL.Count - 1 do
        SLf.Add(SL[j]);
      SLf.SaveToFile(DicName);
    finally
      SLf.Free;
    end;
    FormCreate(sender);
    FormShow(Sender);
  end;
  Screen.Cursor :=crDefault;
end;
//------------------------------------------------
procedure TMain.Memo2Enter(Sender: TObject);
begin
  if radiogroup1.itemindex = 1 then
    exit;
  Button2.Enabled := true;
end;
//------------------------------------------------
procedure TMain.Memo3Enter(Sender: TObject);
begin
  if radiogroup1.itemindex = 1 then exit;
  Button2.Enabled :=true;
end;
//------------------------------------------------
procedure TMain.FormClose(Sender: TObject);
begin
  SL.Free;
end;
//------------------------------------------------
procedure TMain.Button3Click(Sender: TObject);
{$ifdef Linux}
var S: String;
{$endif}
begin
{$ifdef Linux}
  S := ExtractFilePath(GetExeName) + 'Help.htm';
  Shell('netscape ' + S);
  if Shell('kfmclient openURL "' + S + '"') = -1 then
    if Shell('mozilla ' + S) = -1 then
      if Shell('netscape ' + S) = -1 then
        ShowMessage('Sorry, cannot open a browser.');
{$else}
  ShellExecute(Handle, 'open', PChar(ExtractFilePath(GetExeName) + 'Help.htm'), nil, PChar(ExtractFileDrive(GetExeName)), 0);
{$endif}
end;
//----------------------------------------------------------
procedure TMain.Button4Click(Sender: TObject);
var
  i: Integer;
  dumstr2: String;
begin
  dumstr := '';
  dumstr := InputBox(Button4.Caption, Msg[3], dumstr);
  if dumstr <> '' then
  begin
    dumstr2 := '';
    dumstr2 := InputBox(Button4.Caption, Msg[4], dumstr2);
    if dumstr2 <> '' then
    begin
      dumstr := dumstr + ': ' + dumstr2;
      SL.Add(dumstr);
      SL.Sort;
      SL.SaveToFile(DicName);
      {$ifdef Linux}
      Shell('chmod a+w ' + DicName);
      {$endif}
    end;
  end;
end;

procedure TMain.Button5Click(Sender: TObject);
var IniFile: TIniFile;
begin
  with OpenDialog do
  begin
    InitialDir := ExtractFileDir(GetExeName);
    if Execute then
      DicName := FileName;
  end;
  IniFile := TIniFile.Create(IniFileName);
  try
    with IniFile do
    begin
      EraseSection('Setting');
      WriteString('Setting', 'Name of Dictionary', DicName);
      UpdateFile;
    end;
  finally
    IniFile.Free;
  end;
  Edit1.SetFocus;
  LoadDictionary;
end;

function TMain.GetExeName: String;
begin
  Result := Application.ExeName;
end;

initialization
  {$I MainForm.lrs}

end.

